==> aws-cdk.aws-macie-1.135.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_macie_CfnSessionProps(p) {
}
function _aws_cdk_aws_macie_CfnCustomDataIdentifierProps(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.findingCriteria))
        _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty(p.findingCriteria);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_macie_CfnCustomDataIdentifier(p) {
}
function _aws_cdk_aws_macie_CfnSession(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter_CriterionProperty(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnSession, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_CriterionProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-macie-1.145.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_macie_CfnSessionProps(p) {
}
function _aws_cdk_aws_macie_CfnCustomDataIdentifierProps(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.findingCriteria))
        _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty(p.findingCriteria);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_macie_CfnCustomDataIdentifier(p) {
}
function _aws_cdk_aws_macie_CfnSession(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty(p) {
}
function _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnSession, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty };
module.exports.DeprecationError = DeprecationError;
